;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "llama" "20251101.2002"
  "Compact syntax for short lambda."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/llama"
  :commit "e4803de8ab85991b6a944430bb4f543ea338636d"
  :revdesc "e4803de8ab85"
  :keywords '("extensions"))
